@@ -3,9 +3,9 @@ package urpm::media;
 # $Id: media.pm 270394 2010-07-30 00:48:07Z misc $
 
 use strict;
-use urpm 'file_from_local_medium', 'is_local_medium';
+use urpm qw(file_from_local_medium is_local_medium);
 use urpm::msg;
-use urpm::util;
+use urpm::util qw(any append_to_file basename cat_ difference2 dirname member output_safe begins_with copy_and_own file_size offset_pathname reduce_pathname);
 use urpm::removable;
 use urpm::lock;
 use urpm::md5sum;
